/* This file is part of the KDE project
   Copyright (C) 2004 Nadeem Hasan <nhasan@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include "syndock.h"

#include <kiconloader.h>
#include <kdebug.h>
#include <klocale.h>
#include <kpopupmenu.h>

#include <qstring.h>
#include <qwidget.h>
#include <qpixmap.h>
#include <qaction.h>
#include <qpopupmenu.h>
#include <synconfig.h>
#include <qkeysequence.h>

SynDock::SynDock( QWidget *parent, const char *name )
    : KSystemTray( parent, name )
{                    
  // TODO set a tool tip
  m_dockPixmapEnabled = KSystemTray::loadIcon( "ksynaptics" );
  m_dockPixmapDisabled = KSystemTray::loadIcon( "syndockdisabled" );

  setPixmap( m_dockPixmapEnabled );

  m_syndaemonProc = new KProcess();
  m_synclientProc = new KProcess();

  QString delay;
  delay.sprintf( "%2.3f", 0.001f * SynConfig::smartModeDelay() );

  *m_syndaemonProc << "syndaemon" << "-i" << delay << "-t" << "-k";

  if ( ! m_syndaemonProc->start() )
    kdDebug() << "Error: could not launch syndaemon process!" << endl;
  else
    kdDebug() << "launched syndaemon process" << endl;

  QAction *enableDisable =
    new QAction( i18n( "Disable touch pad temporarily" ), QKeySequence( tr( "Ctrl+Alt+D" ) ), this );

  connect( enableDisable, SIGNAL( toggled( bool ) ), this, SLOT( disablePadTemporarily( bool ) ) );

  enableDisable->setToggleAction( true );
  enableDisable->addTo( contextMenu() );
}

SynDock::~SynDock()
{
  if ( ! m_syndaemonProc->kill() )
    kdDebug() << "Error: could not kill syndaemon process!" << endl;
  else
    kdDebug() << "killed syndaemon process" << endl;

  delete m_syndaemonProc;
  delete m_synclientProc;
}

void SynDock::disablePadTemporarily( bool yesNo )
{
  kdDebug() << "switching touch pad " << QString( yesNo? "off":"on" ) << endl;
  m_synclientProc->clearArguments();
  *m_synclientProc << "synclient" << "TouchPadOff=" + QString( yesNo? "1":"0" );
  
  m_synclientProc->start();
  
  setPixmap( yesNo? m_dockPixmapDisabled:m_dockPixmapEnabled );
}

#include "syndock.moc"
